@@ -150,7 +150,7 @@ void GetV4LDevices(std::list<Device>& devices)
 
       if (caps1.type & VID_TYPE_CAPTURE) {
         std::cout << "    Video source can be captured..." << std::endl;
-        for (size_t c=0; c<caps1.channels; c++) {
+        for (int c=0; c<caps1.channels; c++) {
           struct video_channel channel;
 
           channel.channel=c;
@@ -186,7 +186,8 @@ VideoControl::VideoControl()
   storeImage(false),done(false),
   gstMsg(new Lum::Model::Action()),
   knipsed(new Lum::Model::Action()),
-  timer(new Lum::Model::Action())
+  timer(new Lum::Model::Action()),
+  greenColor(0,1,0,Lum::OS::Display::blackColor)
 {
   SetDestroyOnCleanup(false);
 
@@ -317,16 +318,6 @@ void VideoControl::Layout()
 
 #if defined(HAVE_LIB_HILDON)
     videoSinkName="v4l2camsrc";
-#else
-    GetV4LDevices(devices);
-
-    if (devices.size()>0) {
-      videoSinkName=devices.front().gstSink+" device="+devices.front().device;
-    }
-    else {
-      videoSinkName="videotestsrc";
-    }
-#endif
 
     launchString=videoSinkName+" "+
                  "name=videosource ! "
@@ -338,18 +329,32 @@ void VideoControl::Layout()
                  "{ ffmpegcolorspace ! "
                  "video/x-raw-rgb,width=640,height=480,bpp=24 ! "
                  "fakesink name=imagesink }";
-/*
+#else
+    GetV4LDevices(devices);
+
+    if (devices.size()>0) {
+      videoSinkName=devices.front().gstSink+" device="+devices.front().device;
+    }
+    else {
+      videoSinkName="videotestsrc";
+    }
+
     launchString=videoSinkName+" "+
-                 "name=videosource num-buffers=1 ! "
+                 "name=videosource ! "
                  "ffmpegcolorspace ! "
-                 "video/x-raw-yuv,width=640,height=480,bpp=24,framerate=(fraction)25/1 ! "
-                 "xvimagesink name=videosink";*/
+                 "video/x-raw-yuv,width=640,height=480,bpp=24 ! "
+                 "tee name=t ! queue ! "
+                 "{ xvimagesink name=videosink } "
+                 "t. ! queue ! "
+                 "{ ffmpegcolorspace ! "
+                 "video/x-raw-rgb,width=640,height=480,bpp=24 ! "
+                 "fakesink name=imagesink }";
+#endif
 
     std::cout << "Launch string is: \""+launchString+"\"" << std::endl;
 
     // Pipeline elements
-    pipeline=::gst_parse_launch(launchString.c_str(),
-                                &error);
+    pipeline=::gst_parse_launch(launchString.c_str(),&error);
 
     if (pipeline==NULL) {
       std::cerr << "Cannot open video source: " << error << std::endl;
@@ -418,6 +423,21 @@ void VideoControl::RequestImage()
   }
 }
 
+void VideoControl::Draw(Lum::OS::DrawInfo* draw,
+                        int x, int y, size_t w, size_t h)
+{
+  SubWindow::Draw(draw,x,y,w,h);
+
+  std::cout << "Drawing..." << std::endl;
+
+  draw->PushForeground(greenColor);
+  draw->FillRectangle(width/4,height/4,
+                      width/2,height/2);
+  draw->PopForeground();
+
+  std::cout << "Drawing done." << std::endl;
+}
+
 void VideoControl::CancelRequestImage()
 {
   Lum::OS::MutexGuard guard(mutex);
